AsyncSCShareableContentOptions

Struct AsyncSCShareableContentOptions 

pub struct AsyncSCShareableContentOptions { /* private fields */ }
Options for async shareable content retrieval

Implementations

Source

impl AsyncSCShareableContentOptions

pub fn with_exclude_desktop_windows(self, exclude: bool) -> Self

Exclude desktop windows from the shareable content

pub fn with_on_screen_windows_only(self, on_screen_only: bool) -> Self

Include only on-screen windows in the shareable content

pub fn get(self) -> AsyncShareableContentFuture ⓘ

Asynchronously get the shareable content with these options

pub fn below_window( self, reference_window: &SCWindow, ) -> AsyncShareableContentFuture ⓘ

Asynchronously get shareable content with only windows below a reference window

This returns windows that are stacked below the specified reference window in the window layering order.

Arguments
  • reference_window - The window to use as the reference point
pub fn above_window( self, reference_window: &SCWindow, ) -> AsyncShareableContentFuture ⓘ

Asynchronously get shareable content with only windows above a reference window

This returns windows that are stacked above the specified reference window in the window layering order.

Arguments
  • reference_window - The window to use as the reference point